@@ -25,6 +25,7 @@ import warnings
 from abc import ABC, abstractmethod
 from collections import Counter
 from collections.abc import KeysView
+from copy import copy
 from dataclasses import dataclass, field, fields
 from functools import reduce
 from typing import Any, Callable, Dict, List, Optional, Tuple, Type, Union
@@ -37,11 +38,12 @@ from pytorch_lightning.callbacks.early_stopping import EarlyStopping
 from pytorch_lightning.callbacks.lr_monitor import LearningRateMonitor
 from pytorch_lightning.callbacks.model_checkpoint import ModelCheckpoint
 from pytorch_lightning.core.optimizer import _MockOptimizer
-from pytorch_lightning.utilities import _TORCH_GREATER_EQUAL_1_10, rank_zero_info, rank_zero_only, rank_zero_warn
+from pytorch_lightning.utilities import rank_zero_info, rank_zero_only, rank_zero_warn
 from pytorch_lightning.utilities.cloud_io import get_filesystem
 from pytorch_lightning.utilities.exceptions import MisconfigurationException
+from pytorch_lightning.utilities.imports import _TORCH_GREATER_EQUAL_1_10
 from pytorch_lightning.utilities.rank_zero import rank_zero_debug
-from pytorch_lightning.utilities.types import _LRScheduler, LRSchedulerConfig
+from pytorch_lightning.utilities.types import LRSchedulerConfig
 from torch import Tensor
 from torch.nn import Module
 from torch.optim.optimizer import Optimizer
@@ -79,6 +81,23 @@ class FTSState:
         }
 
 
+# todo: improve FTSLRSchedulerType naming/typing once corresponding changes made upstream in pytorch-lightning
+supported_lrs = [
+    "LambdaLR",
+    "MultiplicativeLR",
+    "StepLR",
+    "MultiStepLR",
+    "ExponentialLR",
+    "CosineAnnealingLR",
+    "ReduceLROnPlateau",
+    "CosineAnnealingWarmRestarts",
+]
+if _TORCH_GREATER_EQUAL_1_10:
+    supported_lrs.extend(["ConstantLR", "LinearLR"])
+FTSLRSchedulerTypeTuple = tuple(getattr(torch.optim.lr_scheduler, lr_class) for lr_class in supported_lrs)
+FTSLRSchedulerType = Union[Type[pl.utilities.types._LRScheduler], Type[pl.utilities.types.ReduceLROnPlateau]]
+
+
 class CallbackResolverMixin(ABC):
     """Give user-provided callbacks with the ability to connect to another user-provided callback.
 
@@ -451,9 +470,10 @@ class ScheduleParsingMixin(ABC):
             self._validate_epoch_transitions()
         return max_phase, max_epoch_wm
 
-    def _prune_pl_lrs(self, pl_lrs_cfg: Dict) -> Dict:
+    def _update_pl_lrs(self, pl_lrs_cfg: Dict, lrs_class: FTSLRSchedulerType) -> Dict:
         """Prune keys not part of a valid PyTorch Lightning lr scheduler configuration (if automatic optimization
-        used)
+        used) and update configuration if :external+torch:class:`~torch.optim.lr_scheduler.ReduceLROnPlateau` is
+        used.
 
         Args:
             pl_lrs_cfg (Dict): User-provided PyTorch Lightning lr scheduler configuration
@@ -469,6 +489,16 @@ class ScheduleParsingMixin(ABC):
                     f"Found unsupported keys in the lr scheduler dict: {extra_keys}.",
                     category=RuntimeWarning,
                 )
+            pl_lrs_cfg["reduce_on_plateau"] = pl_lrs_cfg.get(
+                "reduce_on_plateau", issubclass(lrs_class, torch.optim.lr_scheduler.ReduceLROnPlateau)
+            )
+            if pl_lrs_cfg["reduce_on_plateau"] and pl_lrs_cfg.get("monitor", None) is None:
+                raise MisconfigurationException(
+                    "The lr scheduler dict must include a monitor when a `ReduceLROnPlateau` scheduler is used."
+                    ' For example: {"optimizer": optimizer, "lr_scheduler":'
+                    ' {"scheduler": scheduler, "monitor": "your_loss"}}'
+                )
+
         return {k: v for k, v in pl_lrs_cfg.items() if k in supported_keys}
 
     def _pl_lrs_validation(self, pl_lrs_cfg: Dict) -> None:
@@ -506,7 +536,8 @@ class ScheduleParsingMixin(ABC):
             MisconfigurationException: If the configuration provided in `lr_scheduler_init` does not specify a
                 `class_path` for the lr scheduler to be instantiated.
         """
-        if "init_pg_lrs" in target_sched.keys() and (self.reinit_lr_cfg or not depth):
+        implicit_chk = bool(self.reinit_lr_cfg)
+        if "init_pg_lrs" in target_sched.keys() and implicit_chk:
             raise MisconfigurationException(
                 "Specifying a `init_pg_lrs` key in the lr scheduler configuration passed via `reinit_lr_cfg` (i.e. "
                 "implicit mode training) is not a valid configuration since the same lr scheduler configuration "
@@ -542,7 +573,7 @@ class ScheduleParsingMixin(ABC):
             rank_zero_warn(warn_msg)
         lr_scheduler_init = target_sched.get("lr_scheduler_init")
         assert lr_scheduler_init
-        ScheduleParsingMixin._lr_scheduler_sanity_chk(lr_scheduler_init)
+        self._lr_scheduler_sanity_chk(lr_scheduler_init, implicit_chk)
 
     def _lr_scheduler_init_validation(self, lr_reinit_phases: Dict) -> None:
         """Trigger lr scheduler reinitialization configuration validation for all provided configurations. This
@@ -647,9 +678,9 @@ class ScheduleParsingMixin(ABC):
             self._rewrite_schedule(err_msg=err_msg)
 
     def _validate_epoch_transitions(self) -> None:
-        """If not composing :external+pl:class:`~pytorch_lightning.callbacks.early_stopping.EarlyStopping` and epoch-driven
-        stopping criteria (the default behavior) but instead specifying exclusively epoch-driven transitions (
-        :paramref:`~finetuning_scheduler.fts.FinetuningScheduler.epoch_transitions_only` is
+        """If not composing :external+pl:class:`~pytorch_lightning.callbacks.early_stopping.EarlyStopping` and
+        epoch-driven stopping criteria (the default behavior) but instead specifying exclusively epoch-driven
+        transitions ( :paramref:`~finetuning_scheduler.fts.FinetuningScheduler.epoch_transitions_only` is
         ``True``), ensure the specified schedule specifies transitions for every phase.
 
         Raises:
@@ -755,9 +786,9 @@ class ScheduleParsingMixin(ABC):
                 scheduler will be wrapped.
         """
         lr_scheduler_init = new_lr_scheduler["lr_scheduler_init"]
-        lrs_class = ScheduleParsingMixin._import_lr_scheduler(lr_scheduler_init)
+        lrs_class = self._import_lr_scheduler(lr_scheduler_init)
         # unless overridden by user directive, reset optimizer pg lrs to initial before wrapping in new scheduler
-        curr_optimizer_lrs = [group["initial_lr"] for group in optimizer.param_groups]
+        curr_optimizer_lrs = [group.get("initial_lr", group["lr"]) for group in optimizer.param_groups]
         reset_init_pg_lrs = True if new_lr_scheduler.get("init_pg_lrs", None) else False
         initial_optimizer_lrs = new_lr_scheduler.get("init_pg_lrs", curr_optimizer_lrs)
         for _, data in enumerate(zip(optimizer.param_groups, initial_optimizer_lrs)):
@@ -766,10 +797,12 @@ class ScheduleParsingMixin(ABC):
             if reset_init_pg_lrs:
                 param_group["initial_lr"] = lr
         if "pl_lrs_cfg" in new_lr_scheduler.keys():
-            new_lr_scheduler["pl_lrs_cfg"] = self._prune_pl_lrs(new_lr_scheduler["pl_lrs_cfg"])
+            new_lr_scheduler["pl_lrs_cfg"] = self._update_pl_lrs(new_lr_scheduler["pl_lrs_cfg"], lrs_class=lrs_class)
         new_lrs_config = LRSchedulerConfig(
             opt_idx=0,
-            scheduler=lrs_class(optimizer=optimizer, **lr_scheduler_init.get("init_args", {})),
+            scheduler=lrs_class(
+                optimizer=optimizer, **lr_scheduler_init.get("init_args", {})
+            ),  # type: ignore[arg-type]
             **new_lr_scheduler.get("pl_lrs_cfg", {}),
         )
         trainer.strategy.lr_scheduler_configs = [new_lrs_config]
@@ -794,25 +827,35 @@ class ScheduleParsingMixin(ABC):
                     "convertable to a float."
                 )
 
-    @staticmethod
-    def _is_supported_reinit_lr(lr_class: Type[_LRScheduler]) -> None:
-        """Evaulate whether the provided lr scheduler is currently supported in a lr scheduler reinitialization
-        context."""
-        if _TORCH_GREATER_EQUAL_1_10:
-            from torch.optim.lr_scheduler import ChainedScheduler, SequentialLR
+    def _is_supported_lr(self, lr_class: FTSLRSchedulerType) -> None:
+        """Evaulate whether the provided lr scheduler is currently supported.
 
-            unsupported_schedulers = (ChainedScheduler, SequentialLR)
-            if issubclass(lr_class, unsupported_schedulers):
+        Args:
+            lr_class (FTSLRSchedulerType): The lr scheduler class to be inspected for support.
+
+        Raises:
+            MisconfigurationException: If :paramref:`~finetuning_scheduler.fts.FinetuningScheduler.allow_untested` is
+                ``False`` and the provided lr scheduler class is not a subclass allowed by ``FTSLRSchedulerTypeTuple``.
+        """
+        if not issubclass(lr_class, FTSLRSchedulerTypeTuple):
+            if not self.allow_untested:  # type: ignore[attr-defined]
                 error_msg = (
-                    f"The provided lr scheduler type ({lr_class}) is not currently supported in the context of lr "
-                    "scheduler reinitialization. The following lr scheduler types are currently unsupported in lr "
-                    f"reinitialization configurations: { unsupported_schedulers } "
+                    f"The provided lr scheduler ({lr_class}) is not currently supported by"
+                    " FinetuningScheduler. Please use a currently supported torch scheduler (or subclass thereof)"
+                    f" ({([i.__name__ for i in FTSLRSchedulerTypeTuple])}) or if you would like to attempt to use the"
+                    " currently specified scheduler, pass ``allow_untested=True`` to the FinetuningScheduler callback"
+                    " when adding it."
                 )
                 rank_zero_warn(error_msg)
                 raise MisconfigurationException(error_msg)
+            else:
+                warn_msg = (
+                    "Allowing untested scheduler"
+                    f" '{type(lr_class)}' because ``allow_untested`` is ``True``."  # type: ignore[attr-defined]
+                )
+                rank_zero_warn(warn_msg)
 
-    @staticmethod
-    def _import_lr_scheduler(lr_scheduler_init: Dict) -> Type[_LRScheduler]:
+    def _import_lr_scheduler(self, lr_scheduler_init: Dict) -> FTSLRSchedulerType:
         """Import the lr scheduler specified in the provided `lr_scheduler_init` configuration.
 
         Args:
@@ -822,14 +865,13 @@ class ScheduleParsingMixin(ABC):
             MisconfigurationException: If the specified LR scheduler cannot be imported successfully.
 
         Returns:
-            Type[_LRScheduler]: The lr scheduler class to be instantiated.
+            FTSLRSchedulerType: The lr scheduler class to be instantiated.
         """
         try:
             class_module, class_name = lr_scheduler_init["class_path"].rsplit(".", 1)
             module = __import__(class_module, fromlist=[class_name])
             lrs_class = getattr(module, class_name)
-            if _TORCH_GREATER_EQUAL_1_10:
-                ScheduleParsingMixin._is_supported_reinit_lr(lrs_class)
+            self._is_supported_lr(lrs_class)
         except (ImportError, AttributeError) as err:
             error_msg = (
                 f"Could not import specified LR scheduler class using class_path ({lr_scheduler_init['class_path']}) "
@@ -840,8 +882,7 @@ class ScheduleParsingMixin(ABC):
             raise MisconfigurationException(error_msg)
         return lrs_class
 
-    @staticmethod
-    def _lr_scheduler_sanity_chk(lr_scheduler_init: Dict) -> None:
+    def _lr_scheduler_sanity_chk(self, lr_scheduler_init: Dict, is_implicit_mode: bool = False) -> None:
         """Before beginning execution of defined fine-tuning schedule, perform a sanity check of the specified lr
         scheduler reinitialization configuration. To the extent reasonable (i.e. without simulating the entire
         training path), if the provided lr scheduler reinitialization configuration is expected to fail, it is
@@ -854,7 +895,7 @@ class ScheduleParsingMixin(ABC):
             MisconfigurationException: If a valid and supported scheduler cannot be instantiated with the specified
                 init args.
         """
-        lrs_class = ScheduleParsingMixin._import_lr_scheduler(lr_scheduler_init)
+        lrs_class = self._import_lr_scheduler(lr_scheduler_init)
         if lr_scheduler_init.get("init_args") and "optimizer" in lr_scheduler_init.get("init_args", {}).keys():
             warn_msg = (
                 f"Found an `optimizer` key in the provided `lr_scheduler_init`: {lr_scheduler_init['init_args']} "
@@ -864,8 +905,22 @@ class ScheduleParsingMixin(ABC):
             )
             rank_zero_warn(warn_msg)
             del lr_scheduler_init["init_args"]["optimizer"]
+        min_lr_param = lr_scheduler_init["init_args"].get("min_lr")
+        invalid_min_lr = (
+            True if min_lr_param and (isinstance(min_lr_param, list) or isinstance(min_lr_param, tuple)) else False
+        )
+        reinit_rlrop = is_implicit_mode and issubclass(lrs_class, torch.optim.lr_scheduler.ReduceLROnPlateau)
+        if reinit_rlrop and invalid_min_lr:
+            raise MisconfigurationException(
+                "In the lr scheduler configuration passed via `reinit_lr_cfg` (i.e. implicit mode training)"
+                " `min_lr` cannot be a list or tuple since the same lr scheduler configuration is intended to be"
+                " reinitialized at every fine-tuning phase with implicit mode fine-tuning."
+            )
+        test_lr_init = copy(lr_scheduler_init.get("init_args", {}))
+        if min_lr_param:
+            del test_lr_init["min_lr"]  # our mock optimizer will not have any param groups
         try:
-            testlr = lrs_class(optimizer=_MockOptimizer(), **lr_scheduler_init.get("init_args", {}))
+            testlr = lrs_class(optimizer=_MockOptimizer(), **test_lr_init)
         except Exception as err:
             error_msg = (
                 "Could not configure the specified LR scheduler class using the `init_args` "
@@ -874,7 +929,7 @@ class ScheduleParsingMixin(ABC):
             )
             rank_zero_warn(error_msg)
             raise MisconfigurationException(error_msg)
-        assert isinstance(testlr, torch.optim.lr_scheduler._LRScheduler)
+        assert issubclass(type(testlr), FTSLRSchedulerTypeTuple)
 
 
 class ScheduleImplMixin(ABC):
@@ -1090,7 +1145,6 @@ class ScheduleImplMixin(ABC):
         thawed_pl: List,
         no_decay: Optional[list] = None,
         lr: Optional[float] = None,
-        initial_denom_lr: float = 10.0,
         apply_lambdas: bool = False,
     ) -> None:
         """Add optimizer parameter groups associated with the next scheduled fine-tuning depth/level and extend the
@@ -1106,20 +1160,17 @@ class ScheduleImplMixin(ABC):
                 ["bias", "LayerNorm.weight"]. Defaults to ``None``.
             lr: The initial learning rate for the new parameter group(s). If not specified,
                 the ``lr`` of the first scheduled fine-tuning depth will be used. Defaults to ``None``.
-            initial_denom_lr: The scaling factor by which to scale the initial learning rate for new
-                parameter groups when no initial learning rate is specified. Defaults to 10.0.
             apply_lambdas: Whether to apply lr lambdas to newly added groups. Defaults to False.
         """
         if len(thawed_pl) == 0:
             rank_zero_warn("No thawed parameters passed so no new optimizer groups will be added.")
         else:
-            params_lr = optimizer.param_groups[0]["lr"] if lr is None else float(lr)
-            denom_lr = initial_denom_lr if lr is None else 1.0
-            lr_factor = params_lr / denom_lr
-            orig_lr_factor = lr_factor
+            phase_lr = optimizer.param_groups[0]["lr"] if lr is None else float(lr)
+            orig_lr_factor = phase_lr
             for config in module.trainer.lr_scheduler_configs:  # type: ignore[union-attr]
-                if hasattr(config.scheduler, "lr_lambdas") and config.scheduler.lr_lambdas and apply_lambdas:
-                    lr_factor = lr_factor * config.scheduler.lr_lambdas[-1](config.scheduler.last_epoch)
+                scheduler = config.scheduler
+                if hasattr(scheduler, "lr_lambdas") and scheduler.lr_lambdas and apply_lambdas:
+                    phase_lr = phase_lr * scheduler.lr_lambdas[-1](scheduler.last_epoch)
                 added_pgs = 0
                 if no_decay:
                     optimizer.add_param_group(
@@ -1129,8 +1180,8 @@ class ScheduleImplMixin(ABC):
                                 for n, p in module.named_parameters()
                                 if not any(nd in n for nd in no_decay) and n in thawed_pl and p.requires_grad
                             ],
-                            "lr": lr_factor,
-                            "initial_lr": lr_factor,
+                            "lr": phase_lr,
+                            "initial_lr": phase_lr,
                         }
                     )
                     optimizer.add_param_group(
@@ -1141,8 +1192,8 @@ class ScheduleImplMixin(ABC):
                                 if any(nd in n for nd in no_decay) and n in thawed_pl and p.requires_grad
                             ],
                             "weight_decay": 0.0,
-                            "lr": lr_factor,
-                            "initial_lr": lr_factor,
+                            "lr": phase_lr,
+                            "initial_lr": phase_lr,
                         }
                     )
                     added_pgs = 2
@@ -1150,14 +1201,17 @@ class ScheduleImplMixin(ABC):
                     optimizer.add_param_group(
                         {
                             "params": [p for n, p in module.named_parameters() if n in thawed_pl and p.requires_grad],
-                            "lr": lr_factor,
-                            "initial_lr": lr_factor,
+                            "lr": phase_lr,
+                            "initial_lr": phase_lr,
                         }
                     )
                     added_pgs = 1
-                config.scheduler.base_lrs.extend([orig_lr_factor] * added_pgs)
-                if hasattr(config.scheduler, "lr_lambdas"):
-                    config.scheduler.lr_lambdas.extend([config.scheduler.lr_lambdas[-1]] * added_pgs)
+                if isinstance(scheduler, torch.optim.lr_scheduler.ReduceLROnPlateau):
+                    scheduler.min_lrs.extend([scheduler.min_lrs[0]] * added_pgs)  # type: ignore[attr-defined]
+                else:
+                    scheduler.base_lrs.extend([orig_lr_factor] * added_pgs)
+                    if hasattr(scheduler, "lr_lambdas"):
+                        scheduler.lr_lambdas.extend([scheduler.lr_lambdas[-1]] * added_pgs)
 
     @staticmethod
     def sync(objs: Tuple, asets: Tuple, agg_func: Callable = max) -> None:
@@ -1205,6 +1259,51 @@ class ScheduleImplMixin(ABC):
         rank_zero_debug(f"The following module parameters are currently thawed: {[n for n in curr_thawed]}")
         return thawed_p_names, curr_thawed
 
+    @staticmethod
+    def _validate_opt_init(optimizer: Optimizer, ft_schedule: Dict) -> None:
+        """Validate the user-initialized optimizer state (necessary for fine-tuning phase 0) and warn user if
+        appropriate.
+
+        Args:
+            optimizer (Optimizer): The optimizer initialized.
+            ft_schedule (Dict): The fine-tuning schedule to be inspected vis-a-vis the optimizer state.
+        """
+        no_grad_cnt = len([p for pg in optimizer.param_groups for p in pg["params"] if not p.requires_grad])
+        init_ft_cnt = len(ft_schedule[0]["params"])
+        total_ft_cnt = len([p for phase in ft_schedule for p in ft_schedule[phase]["params"]])
+        req_grad_opt = len([p for pg in optimizer.param_groups for p in pg["params"] if p.requires_grad])
+        expected_grad_params = req_grad_opt == init_ft_cnt
+        if no_grad_cnt > 0 or not expected_grad_params:
+            warn_msg = (
+                f"FinetuningScheduler configured the provided model to have {init_ft_cnt} trainable parameters"
+                f" in phase 0 (the initial training phase) but the optimizer has subsequently been initialized with"
+            )
+            if not expected_grad_params:
+                warn_msg += f" {req_grad_opt} trainable parameters. If you have manually"
+                if req_grad_opt > init_ft_cnt:
+                    warn_msg += (
+                        " added additional trainable parameters you may want to ensure the manually added new trainable"
+                        f" parameters do not collide with the {total_ft_cnt} parameters FinetuningScheduler has been"
+                        " scheduled to thaw in the provided schedule."
+                    )
+                else:
+                    warn_msg += (
+                        " removed trainable parameters, you may want to update phase 0 of the provided fine-tuning"
+                        " schedule accordingly"
+                    )
+            else:
+                warn_msg += (
+                    f" {no_grad_cnt} additional parameters that do not require a gradient. If non-intentional, this"
+                    " state is commonly caused by failing to filter out parameters that do not require a gradient when"
+                    " initializing the optimizer (e.g.,"
+                    " `parameters = list(filter(lambda x: x.requires_grad, self.parameters()))`"
+                    f" If you intended to initialize the optimizer with parameters that do not require a"
+                    f" gradient you may want to ensure they are not included in the {total_ft_cnt} parameters that the"
+                    " FinetuningScheduler is currently configured to thaw (sum of all phases) to avoid triggering a "
+                    " parameter collision and training failure in pytorch during a future fine-tuning phase."
+                )
+            rank_zero_warn(warn_msg)
+
 
 class CallbackDepMixin(ABC):
     """Functionality for validating/managing callback dependencies."""
